contexttools.get_tempo_marks_attached_to_component
==================================================

.. autofunction:: abjad.tools.contexttools.get_tempo_marks_attached_to_component.get_tempo_marks_attached_to_component
